@@ -1,13 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Extract COMPDAT, WELSEGS and COMPSEGS from an Eclipse deck
 
 """
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
 
-import argparse
 import datetime
 import logging
 import pandas as pd
@@ -18,10 +13,10 @@ from .common import (
     parse_opmio_deckrecord,
     parse_opmio_date_rec,
     parse_opmio_tstep_rec,
+    write_dframe_stdout_file,
 )
 from .grid import merge_initvectors
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 """OPM authors and Roxar RMS authors have interpreted the Eclipse
@@ -48,16 +43,11 @@ COMPDAT_RENAMER = {
 }
 
 
-def deck2compdatsegsdfs(deck, start_date=None):
-    """Deprecated function name"""
-    logger.warning("Deprecated method name: deck2compdatsegsdfs(), use deck2dfs()")
-    return deck2dfs(deck, start_date)
-
-
 def deck2dfs(deck, start_date=None, unroll=True):
     """Loop through the deck and pick up information found
 
-    The loop over the deck is a state machine, as it has to pick up dates
+    The loop over the deck is a state machine, as it has to pick up dates and
+    potential information from the WELSPECS keyword.
 
     Args:
         deck (opm.libopmcommon_python.Deck): A deck representing the schedule
@@ -73,9 +63,13 @@ def deck2dfs(deck, start_date=None, unroll=True):
     """
     compdatrecords = []  # List of dicts of every line in input file
     compsegsrecords = []
+    welopenrecords = []
     welsegsrecords = []
+    wsegsicdrecords = []
+    wsegaicdrecords = []
+    welspecs = {}
     date = start_date  # DATE column will always be there, but can contain NaN/None
-    for kword in deck:
+    for idx, kword in enumerate(deck):
         if kword.name == "DATES" or kword.name == "START":
             for rec in kword:
                 date = parse_opmio_date_rec(rec)
@@ -92,13 +86,48 @@ def deck2dfs(deck, start_date=None, unroll=True):
                 logger.info(
                     "Advancing %s days to %s through TSTEP", str(days), str(date)
                 )
+        elif kword.name == "WELSPECS":
+            # Information from WELSPECS are to be used in case
+            # 0 or 1* is used in the I or J column in COMPDAT
+            # Only the latest information pr. well is stored.
+            for wellrec in kword:
+                welspecs_rec_dict = parse_opmio_deckrecord(wellrec, "WELSPECS")
+                welspecs[welspecs_rec_dict["WELL"]] = {
+                    "I": welspecs_rec_dict["HEAD_I"],
+                    "J": welspecs_rec_dict["HEAD_J"],
+                }
         elif kword.name == "COMPDAT":
             for rec in kword:  # Loop over the lines inside COMPDAT record
                 rec_data = parse_opmio_deckrecord(
                     rec, "COMPDAT", renamer=COMPDAT_RENAMER
                 )
                 rec_data["DATE"] = date
+                rec_data["KEYWORD_IDX"] = idx
+                if rec_data["I"] == 0:
+                    if rec_data["WELL"] not in welspecs:
+                        raise ValueError(
+                            "WELSPECS must be provided when I is defaulted in COMPDAT"
+                        )
+                    rec_data["I"] = welspecs[rec_data["WELL"]]["I"]
+                if rec_data["J"] == 0:
+                    if rec_data["WELL"] not in welspecs:
+                        raise ValueError(
+                            "WELSPECS must be provided when J is defaulted in COMPDAT"
+                        )
+                    rec_data["J"] = welspecs[rec_data["WELL"]]["J"]
                 compdatrecords.append(rec_data)
+        elif kword.name == "WSEGSICD":
+            for rec in kword:  # Loop over the lines inside WSEGSICD record
+                rec_data = parse_opmio_deckrecord(rec, "WSEGSICD")
+                rec_data["DATE"] = date
+                rec_data["KEYWORD_IDX"] = idx
+                wsegsicdrecords.append(rec_data)
+        elif kword.name == "WSEGAICD":
+            for rec in kword:  # Loop over the lines inside WSEGAICD record
+                rec_data = parse_opmio_deckrecord(rec, "WSEGAICD")
+                rec_data["DATE"] = date
+                rec_data["KEYWORD_IDX"] = idx
+                wsegaicdrecords.append(rec_data)
         elif kword.name == "COMPSEGS":
             wellname = parse_opmio_deckrecord(
                 kword[0], "COMPSEGS", itemlistname="records", recordindex=0
@@ -111,6 +140,18 @@ def deck2dfs(deck, start_date=None, unroll=True):
                 rec_data["WELL"] = wellname
                 rec_data["DATE"] = date
                 compsegsrecords.append(rec_data)
+        elif kword.name == "WELOPEN":
+            for rec in kword:
+                rec_data = parse_opmio_deckrecord(rec, "WELOPEN")
+                rec_data["DATE"] = date
+                rec_data["KEYWORD_IDX"] = idx
+                if rec_data["STATUS"] not in ["OPEN", "SHUT", "STOP", "AUTO"]:
+                    rec_data["STATUS"] = "SHUT"
+                    logger.warning(
+                        "WELOPEN status %s is not a valid "
+                        "COMPDAT state. Using 'SHUT' instead." % rec_data["STATUS"]
+                    )
+                welopenrecords.append(rec_data)
         elif kword.name == "WELSEGS":
             # First record contains meta-information for well
             # (opm deck returns default values for unspecified items.)
@@ -132,22 +173,46 @@ def deck2dfs(deck, start_date=None, unroll=True):
                 if "INFO_TYPE" in rec_data and rec_data["INFO_TYPE"] == "ABS":
                     rec_data["SEGMENT_MD"] = rec_data["SEGMENT_LENGTH"]
                 welsegsrecords.append(rec_data)
-        elif kword.name == "TSTEP":
-            logger.warning("Possible premature stop at first TSTEP")
-            break
 
     compdat_df = pd.DataFrame(compdatrecords)
+    welopen_df = pd.DataFrame(welopenrecords)
 
     if unroll and not compdat_df.empty:
         compdat_df = unrolldf(compdat_df, "K1", "K2")
 
-    compsegs_df = pd.DataFrame(compsegsrecords)
+    if not welopen_df.empty:
+        compdat_df = applywelopen(compdat_df, welopen_df)
 
+    compsegs_df = pd.DataFrame(compsegsrecords)
     welsegs_df = pd.DataFrame(welsegsrecords)
+    wsegsicd_df = pd.DataFrame(wsegsicdrecords)
+    wsegaicd_df = pd.DataFrame(wsegaicdrecords)
+
     if unroll and not welsegs_df.empty:
         welsegs_df = unrolldf(welsegs_df, "SEGMENT1", "SEGMENT2")
 
-    return dict(COMPDAT=compdat_df, COMPSEGS=compsegs_df, WELSEGS=welsegs_df)
+    if unroll and not wsegsicd_df.empty:
+        wsegsicd_df = unrolldf(wsegsicd_df, "SEGMENT1", "SEGMENT2")
+
+    if unroll and not wsegaicd_df.empty:
+        wsegaicd_df = unrolldf(wsegaicd_df, "SEGMENT1", "SEGMENT2")
+
+    if "KEYWORD_IDX" in compdat_df.columns:
+        compdat_df.drop(["KEYWORD_IDX"], axis=1, inplace=True)
+
+    if "KEYWORD_IDX" in wsegsicd_df.columns:
+        wsegsicd_df.drop(["KEYWORD_IDX"], axis=1, inplace=True)
+
+    if "KEYWORD_IDX" in wsegaicd_df.columns:
+        wsegaicd_df.drop(["KEYWORD_IDX"], axis=1, inplace=True)
+
+    return dict(
+        COMPDAT=compdat_df,
+        COMPSEGS=compsegs_df,
+        WELSEGS=welsegs_df,
+        WSEGSICD=wsegsicd_df,
+        WSEGAICD=wsegaicd_df,
+    )
 
 
 def postprocess():
@@ -247,11 +312,105 @@ def unrolldf(dframe, start_column="K1", end_column="K2"):
     return unrolled
 
 
+def applywelopen(compdat_df, welopen_df):
+    """Apply WELOPEN actions to the COMPDAT dataframe.
+
+    Each record in the WELOPEN keyword acts as an operator on existing connections
+    in existing wells.
+
+    Example: COMPDAT and WELOPEN keyword::
+
+      COMPDAT
+       'OP1' 33 44 10 11 'OPEN' /
+       'OP2' 66 44 10 11 'OPEN' /
+      /
+      WELOPEN
+       'OP1' SHUT /
+       'OP2' SHUT 66 44 10 /
+      /
+
+    This deck would define two wells where OP1 and OP2 have two connected grid cells
+    each. Although the COMPDAT defines all connections to be open, WELOPEN overwrites
+    this: all connections in OP1 will be SHUT and in OP2 the upper connection will
+    be SHUT.
+
+    WELOPEN can also be used at different dates and changes therefore the state of
+    connections without explicit use of the COMPDAT keyword. This function translates
+    WELOPEN actions into explicit additional COMPDAT definitions in the exported df.
+
+    Args:
+        compdat_df (pd.DataFrame): Dataframe with unrolled COMPDAT data
+        welopen_df (pd.DataFrame): Dataframe with WELOPEN actions
+
+    Returns:
+        pd.Dataframe, compdat_df now including WELOPEN actions
+
+    """
+    welopen_df = welopen_df.astype(object).where(pd.notnull(welopen_df), None)
+    for _, row in welopen_df.iterrows():
+        if row["I"] and row["J"] and row["K"]:
+            previous_state = compdat_df[
+                (compdat_df["WELL"] == row["WELL"])
+                & (compdat_df["KEYWORD_IDX"] < row["KEYWORD_IDX"])
+                & (compdat_df["I"] == row["I"])
+                & (compdat_df["J"] == row["J"])
+                & (compdat_df["K1"] == row["K"])
+                & (compdat_df["K2"] == row["K"])
+            ].drop_duplicates(subset=["I", "J", "K1", "K2"], keep="last")
+        elif row["C1"] or row["C2"]:
+            logger.warning(
+                "Lumped connections are not supported in a WELOPEN keyword. "
+                "Skipping WELOPEN actions for lumped connections '%s' and/or '%s'"
+                % (row["C1"], row["C2"])
+            )
+            continue
+        elif not (row["I"] and row["J"] and row["K"]):
+            previous_state = compdat_df[
+                (compdat_df["WELL"] == row["WELL"])
+                & (compdat_df["KEYWORD_IDX"] < row["KEYWORD_IDX"])
+            ].drop_duplicates(subset=["I", "J", "K1", "K2"], keep="last")
+        else:
+            raise ValueError(
+                "A WELOPEN keyword contains data that could not be parsed. "
+                "(I=%s,J=%s,K=%s)" % (row["I"], row["J"], row["K"])
+            )
+
+        if previous_state.empty:
+            raise ValueError(
+                "A WELOPEN keyword is not acting on any existing connection. "
+                "(I=%s,J=%s,K=%s)" % (row["I"], row["J"], row["K"])
+            )
+
+        new_state = previous_state
+
+        # The COMPDAT DataFrame uses COMPDAT_RENAMER and therefore uses "OP/SH" as a
+        # column name for the state of a well. WELOPEN uses "STATUS" for the state
+        # column name and therefore a translation step needs to be done. The
+        # underlying problem is that the opm-common definitions for the state of a
+        # well in COMPDAT and WELOPEN are not identical. These translation steps can
+        # be dropped when unity in the opm-common keyword definitions is reached.
+        new_state["OP/SH"] = row["STATUS"]
+        new_state["KEYWORD_IDX"] = row["KEYWORD_IDX"]
+        new_state["DATE"] = row["DATE"]
+
+        compdat_df = compdat_df.append(new_state)
+
+    if not compdat_df.empty:
+        compdat_df = (
+            compdat_df.sort_values(by=["KEYWORD_IDX"])
+            .drop_duplicates(subset=["I", "J", "K1", "K2", "DATE"], keep="last")
+            .reset_index(drop=True)
+        )
+
+    return compdat_df
+
+
 def fill_parser(parser):
     """Set up sys.argv parsers.
 
     Arguments:
-        parser (argparse.ArgumentParser or argparse.subparser): parser to fill with arguments
+        parser (argparse.ArgumentParser or argparse.subparser): parser
+            to fill with arguments
     """
     parser.add_argument("DATAFILE", help="Name of Eclipse DATA file.")
     parser.add_argument(
@@ -271,26 +430,15 @@ def fill_parser(parser):
     return parser
 
 
-def main():
-    """Entry-point for module, for command line utility
-    """
-    logger.warning("compdat2csv is deprecated, use 'ecl2csv compdat <args>' instead")
-    parser = argparse.ArgumentParser()
-    parser = fill_parser(parser)
-    args = parser.parse_args()
-    compdat_main(args)
-
-
 def compdat_main(args):
     """Entry-point for module, for command line utility"""
     if args.verbose:
-        logger.setLevel(logging.INFO)
+        logging.basicConfig(level=logging.INFO)
     eclfiles = EclFiles(args.DATAFILE)
     compdat_df = df(eclfiles, initvectors=args.initvectors)
     if compdat_df.empty:
         logger.warning("Empty COMPDAT data being written to disk!")
-    compdat_df.to_csv(args.output, index=False)
-    print("Wrote to " + args.output)
+    write_dframe_stdout_file(compdat_df, args.output, index=False, caller_logger=logger)
 
 
 def df(eclfiles, initvectors=None):
