@@ -1,23 +1,15 @@
-#!/usr/bin/env python
-
-# -*- coding: utf-8 -*-
 """
 Extract EQUIL from an Eclipse deck as Pandas DataFrame
 
 """
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
 
-import sys
+import signal
 import logging
-import argparse
 import pandas as pd
 
 from ecl2df import inferdims, common
 from .eclfiles import EclFiles
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 SUPPORTED_KEYWORDS = ["EQUIL", "PBVD", "PDVD", "RSVD", "RVVD"]
@@ -72,12 +64,6 @@ RENAMERS["oil-gas"] = {
 }
 
 
-def deck2equildf(deck):
-    """Deprecated function name"""
-    logger.warning("Deprecated function name, deck2equildf")
-    return deck2df(deck)
-
-
 def df(deck, keywords=None, ntequl=None):
     """Extract EQUIL related keyword data, EQUIL, RSVD, RVVD
     PBVD and PDVD.
@@ -272,12 +258,6 @@ def equil_fromdeck(deck, ntequl=None):
     return dataframe
 
 
-def deck2df(eclfiles, ntequl=None):
-    """Wrapper for deprecated syntax (does not support the keywords argument)"""
-    logger.warning("Deprecated function name equil.deck2df(). Use equil.df()")
-    return df(eclfiles, ntequl=ntequl)
-
-
 def fill_parser(parser):
     """Set up sys.argv parsers.
 
@@ -311,20 +291,10 @@ def fill_reverse_parser(parser):
     return common.fill_reverse_parser(parser, "EQUIL, RSVD++", "solution.inc")
 
 
-def main():
-    """Entry-point for module, for command line utility
-    """
-    logger.warning("equil2csv is deprecated, use 'ecl2csv equil <args>' instead")
-    parser = argparse.ArgumentParser()
-    parser = fill_parser(parser)
-    args = parser.parse_args()
-    equil_main(args)
-
-
 def equil_main(args):
     """Read from disk and write CSV back to disk"""
     if args.verbose:
-        logger.setLevel(logging.INFO)
+        logging.basicConfig(level=logging.INFO)
     eclfiles = EclFiles(args.DATAFILE)
     if eclfiles:
         deck = eclfiles.get_ecldeck()
@@ -337,21 +307,18 @@ def equil_main(args):
         # EQLDIMS. Then we send it to df() as a string
         equil_df = df("".join(open(args.DATAFILE).readlines()))
     if not equil_df.empty:
-        if args.output == "-":
-            # Ignore pipe errors when writing to stdout.
-            from signal import signal, SIGPIPE, SIG_DFL
-
-            signal(SIGPIPE, SIG_DFL)
-            equil_df.to_csv(sys.stdout, index=False)
-        else:
-            logger.info(
-                "Unique EQLNUMs: %d, keywords: %s",
-                len(equil_df["EQLNUM"].unique()),
-                str(equil_df["KEYWORD"].unique()),
-            )
-            equil_df.to_csv(args.output, index=False)
-            print("Wrote to " + args.output)
-
+        common.write_dframe_stdout_file(
+            equil_df,
+            args.output,
+            index=False,
+            caller_logger=logger,
+            logstr=(
+                "Unique EQLNUMs: {}, keywords: {}".format(
+                    str(len(equil_df["EQLNUM"].unique())),
+                    str(equil_df["KEYWORD"].unique()),
+                )
+            ),
+        )
     else:
         logger.error("Empty EQUIL-data, not written to disk!")
 
@@ -359,16 +326,14 @@ def equil_main(args):
 def equil_reverse_main(args):
     """Entry-point for module, for command line utility for CSV to Eclipse"""
     if args.verbose:
-        logger.setLevel(logging.INFO)
+        logging.basicConfig(level=logging.INFO)
     equil_df = pd.read_csv(args.csvfile)
     logger.info("Parsed %s", args.csvfile)
     inc_string = df2ecl(equil_df, keywords=args.keywords)
 
     if args.output == "-":
         # Ignore pipe errors when writing to stdout.
-        from signal import signal, SIGPIPE, SIG_DFL
-
-        signal(SIGPIPE, SIG_DFL)
+        signal.signal(signal.SIGPIPE, signal.SIG_DFL)
         print(inc_string)
     else:
         with open(args.output, "w") as f_handle:
