@@ -1,25 +1,17 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Extract the contents of the FAULTS keyword into
 a DataFrame
 
 """
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-
 import logging
-import argparse
 import pandas as pd
 
 from .eclfiles import EclFiles
 from .common import parse_opmio_deckrecord
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
-
 RECORD_COLUMNS = ["NAME", "IX1", "IX2", "IY1", "IY2", "IZ1", "IZ2", "FACE"]
 COLUMNS = ["NAME", "I", "J", "K", "FACE"]
 ALLOWED_FACES = ["X", "Y", "Z", "I", "J", "K", "X-", "Y-", "Z-", "I-", "J-", "K-"]
@@ -74,20 +66,10 @@ def fill_parser(parser):
     return parser
 
 
-def main():
-    """Entry-point for module, for command line utility
-    """
-    logger.warning("faults2csv is deprecated, use 'ecl2csv faults <args>' instead")
-    parser = argparse.ArgumentParser()
-    parser = fill_parser(parser)
-    args = parser.parse_args()
-    faults_main(args)
-
-
 def faults_main(args):
     """Read from disk and write CSV back to disk"""
     if args.verbose:
-        logger.setLevel(logging.INFO)
+        logging.basicConfig(level=logging.INFO)
     eclfiles = EclFiles(args.DATAFILE)
     if eclfiles:
         deck = eclfiles.get_ecldeck()
