@@ -5,15 +5,13 @@ Extract FIP region reports from Eclipse PRT file
 """
 
 import re
-import sys
 import logging
 import datetime
 import pandas as pd
 
 from .eclfiles import EclFiles
-from .common import parse_ecl_month
+from .common import parse_ecl_month, write_dframe_stdout_file
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 REGION_REPORT_COLUMNS = [
@@ -150,9 +148,11 @@ def df(prtfile, fipname="FIPNUM"):
                 if not sum([string in line for string in interesting_strings]):
                     # Skip if we are not on an interesting line.
                     continue
-                # The colons in the report block are not reliably included (wtf!), even in the
-                # same PRT file. We insert them in fixed positions and hope for the best
-                # (if the ASCII table is actually dynamic with respect to content, this will fail)
+                # The colons in the report block are not reliably included
+                # (differs by Eclipse version), even in the same PRT file. We
+                # insert them in fixed positions and hope for the best (if the
+                # ASCII table is actually dynamic with respect to content, this
+                # will fail)
                 linechars = list(line)
                 linechars[1] = ":"
                 linechars[27] = ":"
@@ -182,19 +182,10 @@ def fill_parser(parser):
 def fipreports_main(args):
     """Command line API"""
     if args.verbose:
-        logger.setLevel(logging.INFO)
+        logging.basicConfig(level=logging.INFO)
     if args.PRTFILE.endswith(".PRT"):
         prtfile = args.PRTFILE
     else:
         prtfile = EclFiles(args.PRTFILE).get_prtfilename()
     dframe = df(prtfile, args.fipname)
-    if args.output == "-":
-        # Ignore pipe errors when writing to stdout.
-        from signal import signal, SIGPIPE, SIG_DFL
-
-        signal(SIGPIPE, SIG_DFL)
-        dframe.to_csv(sys.stdout, index=False)
-    else:
-        logger.info("Writing output to disk")
-        dframe.to_csv(args.output, index=False)
-        print("Wrote to " + args.output)
+    write_dframe_stdout_file(dframe, args.output, index=False, caller_logger=logger)
