@@ -1,20 +1,14 @@
-# -*- coding: utf-8 -*-
 """
 Extract non-neighbour connection (NNC) information from Eclipse output files.
 """
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-
 import os
 import logging
 import datetime
-import argparse
 import pandas as pd
+from pathlib import Path
 
 from ecl2df import common, EclFiles, grid, __version__
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
@@ -202,7 +196,8 @@ def fill_parser(parser):
 def df2ecl_editnnc(nnc_df, filename=None, nocomments=False):
     """Write an EDITNNC keyword
 
-    This will write
+    This will write::
+
         EDITNNC
            IX IY IZ JX JY JZ TRANM /
            ...
@@ -270,33 +265,15 @@ def df2ecl_editnnc(nnc_df, filename=None, nocomments=False):
     string += "\n\n"
 
     if filename is not None:
-        # Make directory if not present:
-        filenamedir = os.path.dirname(filename)
-        if filenamedir and not os.path.exists(filenamedir):
-            os.makedirs(filenamedir)
-        with open(filename, "w") as file_handle:
-            file_handle.write(string)
-
+        Path(filename).parent.mkdir(parents=True, exist_ok=True)
+        Path(filename).write_text(string, encoding="utf-8")
     return string
 
 
-def main():
-    """Entry-point for module, for command line utility
-
-    It may become deprecated to have a main() function
-    and command line utility for each module in ecl2df
-    """
-    logger.warning("nnc2csv is deprecated, use 'ecl2csv nnc <args>' instead")
-    parser = argparse.ArgumentParser()
-    fill_parser(parser)
-    args = parser.parse_args()
-    nnc_main(args)
-
-
 def nnc_main(args):
     """Command line access point from main() or from ecl2csv via subparser"""
     if args.verbose:
-        logger.setLevel(logging.INFO)
+        logging.basicConfig(level=logging.INFO)
     eclfiles = EclFiles(args.DATAFILE)
     nncdf = df(eclfiles, coords=args.coords, pillars=args.pillars)
     if nncdf.empty:
