@@ -1,29 +1,48 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-"""
-Provide a Pandas DataFrame interface to Eclipse summary data (UNSMRY)
-
-Code taken from fmu.ensemble.ScratchRealization
-"""
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-
-import os
-import sys
+"""Provide a two-way Pandas DataFrame interface to Eclipse summary data (UNSMRY)"""
 import logging
-import argparse
 import datetime
-import dateutil.parser
+from pathlib import Path
 
+import dateutil.parser
 import pandas as pd
 
+from ecl.summary import EclSum
+
 from .eclfiles import EclFiles
 from . import parameters
+from .common import write_dframe_stdout_file
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
+PD_FREQ_MNEMONICS = {
+    "monthly": "MS",
+    "yearly": "YS",
+    "daily": "D",
+    "weekly": "W-MON",
+}
+"""Mapping from ecl2df custom offset strings to Pandas DateOffset strings.
+See
+https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#dateoffset-objects
+"""  # noqa
+
+
+def date_range(start_date, end_date, freq):
+    """Wrapper for pandas.date_range to allow for extra ecl2df specific mnemonics
+    'yearly', 'daily', 'weekly', mapped over to pandas DateOffsets.
+
+    Args:
+        start_date (datetime.date):
+        end_date (datetime.date):
+        freq (str): monthly, daily, weekly, yearly, or a Pandas date offset
+            frequency.
+
+    Returns:
+        list of datetimes
+    """
+    if freq in PD_FREQ_MNEMONICS:
+        freq = PD_FREQ_MNEMONICS[freq]
+    return pd.date_range(start_date, end_date, freq=freq)
+
 
 def normalize_dates(start_date, end_date, freq):
     """
@@ -44,25 +63,10 @@ def normalize_dates(start_date, end_date, freq):
     Return:
         Tuple of normalized (start_date, end_date)
     """
-    from dateutil.relativedelta import relativedelta
-
-    if freq == "monthly":
-        start_date = start_date.replace(day=1)
-
-        # Avoid rolling forward if we are already at day 1 in a month
-        if end_date != end_date.replace(day=1):
-            end_date = end_date.replace(day=1) + relativedelta(months=1)
-    elif freq == "yearly":
-        start_date = start_date.replace(day=1, month=1)
-        # Avoid rolling forward if we are already at day 1 in a year
-        if end_date != end_date.replace(day=1, month=1):
-            end_date = end_date.replace(day=1, month=1) + relativedelta(years=1)
-    elif freq == "daily":
-        # This we don't need to normalize, but we should not give any warnings
-        pass
-    else:
-        raise ValueError("Unrecognized frequency for date normalization: " + str(freq))
-    return (start_date, end_date)
+    if freq in PD_FREQ_MNEMONICS:
+        freq = PD_FREQ_MNEMONICS[freq]
+    offset = pd.tseries.frequencies.to_offset(freq)
+    return (offset.rollback(start_date).date(), offset.rollforward(end_date).date())
 
 
 def resample_smry_dates(
@@ -141,8 +145,6 @@ def resample_smry_dates(
     start_smry = min(eclsumsdates)
     end_smry = max(eclsumsdates)
 
-    pd_freq_mnenomics = {"monthly": "MS", "yearly": "YS", "daily": "D"}
-
     (start_n, end_n) = normalize_dates(start_smry.date(), end_smry.date(), freq)
 
     if not start_date and not normalize:
@@ -159,11 +161,8 @@ def resample_smry_dates(
     else:
         end_date_range = end_date
 
-    if freq not in pd_freq_mnenomics:
-        raise ValueError("Requested frequency %s not supported" % freq)
-    datetimes = pd.date_range(
-        start_date_range, end_date_range, freq=pd_freq_mnenomics[freq]
-    )
+    datetimes = date_range(start_date_range, end_date_range, freq)
+
     # Convert from Pandas' datetime64 to datetime.date:
     datetimes = [x.date() for x in datetimes]
 
@@ -186,7 +185,7 @@ def df(
     include_restart=True,
     params=False,
     paramfile=None,
-    datetime=False,
+    datetime=False,  # A very poor choice of argument name [pylint]
 ):
     """
     Extract data from UNSMRY as Pandas dataframes.
@@ -195,7 +194,8 @@ def df(
     support for string mnenomics for the time index.
 
     Arguments:
-        eclfiles: EclFiles object representing the Eclipse deck.
+        eclfiles: EclFiles object representing the Eclipse deck. Alternatively
+           an EclSum object.
         time_index: string indicating a resampling frequency,
            'yearly', 'monthly', 'daily', 'last' or 'raw', the latter will
            return the simulated report steps (also default).
@@ -246,9 +246,11 @@ def df(
         column_keys_str,
         str(time_index_arg or "raw"),
     )
-    dframe = eclfiles.get_eclsum(include_restart=include_restart).pandas_frame(
-        time_index_arg, column_keys
-    )
+    if isinstance(eclfiles, EclSum):
+        eclsum = eclfiles
+    else:
+        eclsum = eclfiles.get_eclsum(include_restart=include_restart)
+    dframe = eclsum.pandas_frame(time_index_arg, column_keys)
     # If time_index_arg was None, but start_date was set, we need to date-truncate
     # afterwards:
     logger.info(
@@ -263,7 +265,7 @@ def df(
             logger.info("Loading parameters from files: %s", str(param_files))
             param_dict = parameters.load_all(param_files)
         else:
-            if not os.path.isabs(paramfile):
+            if not Path(paramfile).is_absolute():
                 param_file = parameters.find_parameter_files(
                     eclfiles, filebase=paramfile
                 )
@@ -285,6 +287,76 @@ def df(
     return dframe
 
 
+def _fix_dframe_for_libecl(dframe: pd.DataFrame) -> pd.DataFrame:
+    """Fix a dataframe making it ready for EclSum.from_pandas()
+
+    * Ensures that the index is always datetime, and sorted.
+    * Removes BLOCK vectors, these are currently not supported as
+      it requires knowledge of the grid dimensions. Warnings
+      will be emitted for skipped columns
+
+    Args:
+        dframe (pd.DataFrame): Dataframe to read. Will not be modified.
+
+    Returns:
+        pd.DataFrame: Modified copy of incoming dataframe.
+    """
+    if dframe.empty:
+        return dframe
+    dframe = dframe.copy()
+    if "DATE" in dframe.columns:
+        dframe["DATE"] = pd.to_datetime(dframe["DATE"])
+        dframe = dframe.set_index("DATE", drop=True)
+    if not isinstance(dframe.index, pd.DatetimeIndex):
+        raise ValueError("dataframe must have a DatetimeIndex")
+    dframe.sort_index(axis=0, inplace=True)
+
+    # This column will appear if dataframes are naively written to CSV
+    # files and read back in again.
+    if "Unnamed: 0" in dframe:
+        dframe.drop("Unnamed: 0", axis="columns", inplace=True)
+
+    block_columns = [
+        col for col in dframe.columns if (col.startswith("B") or col.startswith("LB"))
+    ]
+    if block_columns:
+        dframe = dframe.drop(columns=block_columns)
+        logger.warning(
+            "Dropped columns with block data, not supported: %s",
+            str({colname.partition(":")[0] + ":*" for colname in block_columns}),
+        )
+
+    return dframe
+
+
+def df2eclsum(
+    dframe: pd.DataFrame,
+    casename: str = "SYNTHETIC",
+):
+    """Convert a dataframe to an EclSum object
+
+    Args:
+        dframe (pd.DataFrame): Dataframe with a DATE colum (or with the
+            dates/datetimes in the index).
+        casename: Name of Eclipse casename/basename to be used for the EclSum object
+            If the EclSum object is later written to disk, this will be used
+            to construct the filenames.
+
+    Returns:
+        EclSum
+    """
+    if dframe.empty:
+        return None
+
+    if casename.upper() != casename:
+        raise ValueError(f"casename {casename} must be UPPER CASE")
+    if "." in casename:
+        raise ValueError(f"Do not use dots in casename {casename}")
+
+    dframe = _fix_dframe_for_libecl(dframe)
+    return EclSum.from_pandas(casename, dframe)
+
+
 def fill_parser(parser):
     """Set up sys.argv parsers.
 
@@ -366,21 +438,23 @@ def fill_parser(parser):
     return parser
 
 
-def main():
-    """Entry-point for module, for command line utility
-    """
-    logger.warning("summary2csv is deprecated, use 'ecl2csv smry <args>' instead")
-    parser = argparse.ArgumentParser(description="Convert Eclipse UNSMRY files to CSV")
-    parser = fill_parser(parser)
-    args = parser.parse_args()
-    summary_main(args)
+def fill_reverse_parser(parser):
+    """Fill a parser for the operation:  dataframe -> eclsum files"""
+    parser.add_argument("csvfile", help="Name of CSV file with summary data.")
+    parser.add_argument("ECLBASE", help="Basename for Eclipse output files")
+    parser.add_argument("-v", "--verbose", action="store_true", help="Be verbose")
+    parser.add_argument("--debug", action="store_true", help="Be verbose")
+    return parser
 
 
 def summary_main(args):
     """Read summary data from disk and write CSV back to disk"""
     if args.verbose:
-        logger.setLevel(logging.INFO)
-    eclfiles = EclFiles(args.DATAFILE)
+        logging.basicConfig(level=logging.INFO)
+    eclbase = (
+        args.DATAFILE.replace(".DATA", "").replace(".UNSMRY", "").replace(".SMSPEC", "")
+    )
+    eclfiles = EclFiles(eclbase)
     sum_df = df(
         eclfiles,
         time_index=args.time_index,
@@ -392,13 +466,21 @@ def summary_main(args):
     )
     if sum_df.empty:
         logger.warning("Empty summary data being written to disk!")
-    if args.output == "-":
-        # Ignore pipe errors when writing to stdout.
-        from signal import signal, SIGPIPE, SIG_DFL
+    write_dframe_stdout_file(sum_df, args.output, logger)
 
-        signal(SIGPIPE, SIG_DFL)
-        sum_df.to_csv(sys.stdout, index=True)
-    else:
-        logger.info("Writing to file %s", str(args.output))
-        sum_df.to_csv(args.output, index=True)
-        print("Wrote to " + args.output)
+
+def summary_reverse_main(args):
+    """Entry point for usage with "csv2ecl summary" on the command line"""
+    if args.verbose and not args.debug:
+        logging.basicConfig(level=logging.INFO)
+    if args.debug:
+        logging.basicConfig(level=logging.DEBUG)
+
+    summary_df = pd.read_csv(args.csvfile)
+    logger.info("Parsed %s", args.csvfile)
+
+    eclsum = df2eclsum(summary_df, args.ECLBASE)
+    EclSum.fwrite(eclsum)
+    logger.info(
+        "Wrote to %s and %s", args.ECLBASE + ".UNSMRY", args.ECLBASE + ".SMSPEC"
+    )
